Method: Hash#deep_stringify_keys

Defined in:
lib/ext/hash/keys.rb

#deep_stringify_keysObject

Returns a new hash with all keys converted to strings. This includes the keys from the root hash and from all nested hashes.

hash = { person: { name: 'Rob', age: '28' } }

hash.deep_stringify_keys
# => {"person"=>{"name"=>"Rob", "age"=>"28"}}


111
112
113
# File 'lib/ext/hash/keys.rb', line 111

def deep_stringify_keys
  deep_transform_keys{ |key| key.to_s }
end